@@ -5,7 +5,10 @@ The output format is JSON as described in
 https://docs.sonarqube.org/latest/analysis/generic-issue/
 """
 
-from pylint.lint.pylinter import PyLinter
+try:
+    from pylint.lint.pylinter import PyLinter
+except ImportError:
+    from pylint.lint import PyLinter
 from pylint_plugin_utils import get_checker
 
 from .sonarjson_reporter import SonarJSONReporter
